@@ -18,7 +18,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: affile.c,v 1.15 1999/06/08 19:47:31 bazsi Exp $
+ * $Id: affile.c,v 1.16 1999/07/10 15:58:33 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -26,6 +26,7 @@
 #include "format.h"
 #include "pkt_buffer.h"
 #include "cfgfile.h"
+#include "utils.h"
 
 #include <fcntl.h>
 #include <assert.h>
@@ -97,6 +98,7 @@ struct log_source_driver *make_affile_source(const char *name)
          (name string)
          (flags simple int)
          (dest object io_fd)
+	 (dest_buf object abstract_buffer)
 	 (sync_freq simple UINT32)))
 */
 
@@ -106,6 +108,18 @@ void affile_set_syncfreq(struct log_dest_driver *c, int syncfreq)
 	self->sync_freq = syncfreq;
 }
 
+void affile_set_compress(struct log_dest_driver *c, int enable)
+{
+	CAST(affile_dest, self, c);
+	self->flags = set_flags(self->flags, AFFILE_COMPRESS, AFFILE_COMPRESS_SHIFT, enable);
+}
+
+void affile_set_encrypt(struct log_dest_driver *c, int enable)
+{
+	CAST(affile_dest, self, c);
+	self->flags = set_flags(self->flags, AFFILE_ENCRYPT, AFFILE_ENCRYPT_SHIFT, enable);
+}
+
 static int do_init_affile_dest(struct log_handler *c, struct syslog_conf *cfg)
 {
 	CAST(affile_dest, self, c);
@@ -113,25 +127,31 @@ static int do_init_affile_dest(struct log_handler *c, struct syslog_conf *cfg)
 	
 	if (self->sync_freq == -1)
 		self->sync_freq = cfg->sync_freq;
+	if (self->super.log_fifo_size == -1)
+		self->super.log_fifo_size = cfg->log_fifo_size;
 	/* self->cfg = cfg;*/
+	if (self->dest)
+		self->dest->buffer = NULL;
+	if (!self->dest_buf)
+		self->dest_buf = make_pkt_buffer_ext(self->sync_freq, 
+				    MAX(self->super.log_fifo_size + 1, 
+					self->sync_freq));
 	self->dest = NULL;
 	if (do_open_file(self->name, O_WRONLY | O_CREAT | O_APPEND | O_NOCTTY | O_NONBLOCK, 0600, &fd)) {
 		struct resource_node *res;
 
 		self->dest = io_write(make_io_fd(cfg->backend, fd), 
-				      make_pkt_buffer_ext(self->sync_freq, 
-							  MAX(LOG_FIFO_SIZE + 1, 
-							      self->sync_freq)),
+				      self->dest_buf,
 				      NULL);
 		res = REMEMBER_RESOURCE(cfg->resources, &self->dest->super.super);
-		self->dest->super.close_callback = make_dest_close(c, res, TIME_REOPEN, cfg);
+		self->dest->super.close_callback = make_dest_close(c, res, cfg->time_reopen, cfg);
 		/* self->attempts = 0; */
 	}
 	else {
 		if (errno == ENXIO) {
 			/* opening the write side of the fifo failed */
 			/* self->attempts++; */
-			io_callout(cfg->backend, TIME_REOPEN, make_dest_reopen(c, cfg));
+			io_callout(cfg->backend, cfg->time_reopen, make_dest_reopen(c, cfg));
 		}
 		else {
 			werror("Cannot open file %S for writing (%z)\n", self->name, strerror(errno));
@@ -145,8 +165,8 @@ static void do_handle_affile_log(struct log_handler *c, struct log_info *msg)
 {
 	CAST(affile_dest, self, c);
 
-	if (self->dest && self->dest->buffer) {
-		A_WRITE_STRING(&self->dest->buffer->super, c_format("%S %S %S\n", msg->date, msg->host, msg->msg));
+	if (self->dest_buf) {
+		A_WRITE_STRING(&self->dest_buf->super, c_format("%S %S %S\n", msg->date, msg->host, msg->msg));
 	}
 	log_info_free(msg);
 }
@@ -157,6 +177,7 @@ struct log_dest_driver *make_affile_dest(const char *name, int flags)
 	
 	self->super.super.init = do_init_affile_dest;
 	self->super.super.handler = do_handle_affile_log;
+	self->super.log_fifo_size = -1;
 	self->name = c_format_cstring("%z", name);
 	self->flags = flags;
 	self->sync_freq = -1; /* use global setting */
