@@ -106,6 +106,16 @@ static int do_init_afsocket_source_connection(
 static void do_handle_afinet_line(struct log_handler *c, struct log_info *msg)
 {
 	CAST(afsocket_source_connection, self, c);
+	if (!msg->saddr) {
+		char sockaddr_buf[256];
+		struct sockaddr *sa = (struct sockaddr *) &sockaddr_buf;
+		int salen = sizeof(sockaddr_buf);
+
+		if (getpeername(self->fd, sa, &salen) != -1) {
+			msg->saddr = ol_space_alloc(salen);
+			memcpy(msg->saddr, sa, salen);
+		}
+	}
 	HANDLE_LOG(self->super.next, msg);
 }
 
