@@ -18,7 +18,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: afsocket.h,v 1.6 1999/06/08 19:47:31 bazsi Exp $
+ * $Id: afsocket.h,v 1.7 1999/07/10 15:58:33 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -28,6 +28,8 @@
 #include "syslog-ng.h"
 #include "io.h"
 #include "sources.h"
+#include "destinations.h"
+#include "utils.h"
 
 #define AFSOCKET_STREAM		0x0000
 #define AFSOCKET_DGRAM		0x0001
@@ -39,6 +41,23 @@
 #define AFUNIX_PROTO_STREAM	(AFSOCKET_STREAM | AFSOCKET_UNIX)
 #define AFUNIX_PROTO_DGRAM	(AFSOCKET_DGRAM | AFSOCKET_UNIX)
 
+#define AFSOCKET_REQUIRED       2
+#define AFSOCKET_ALLOW          1
+#define AFSOCKET_DENY           0
+
+#define AFSOCKET_YES            3
+#define AFSOCKET_NO             0
+
+#define AFSOCKET_AUTH_MASK      0x000C
+#define AFSOCKET_AUTH_SHIFT     2
+
+#define AFSOCKET_MAC_MASK       0x0030
+#define AFSOCKET_MAC_SHIFT      4
+
+#define AFSOCKET_ENCRYPT_MASK   0x00C0
+#define AFSOCKET_ENCRYPT_SHIFT  6
+
+
 #define AFSOCKET_TYPE		0x0001
 #define AFSOCKET_PROTO          0x0002
 
@@ -46,24 +65,25 @@
 #include "afsocket.h.x"
 #undef CLASS_DECLARE
 
-/* CLASS:
-   (class
-     (name socket_addr)
-     (vars
-       (bind method int "int fd")
-       (connect method int "int fd")
-       (sa special "struct sockaddr *" #f free_sockaddr)
-       (salen simple int)))
-*/
+void afunix_set_owner(struct log_source_driver *c, const char *owner);
+void afunix_set_group(struct log_source_driver *c, const char *group);
+void afunix_set_perm(struct log_source_driver *c, int perm);
 
-#define BIND_SOCKET(a, f) ((a)->bind(a, f))
-#define CONNECT_SOCKET(a, f) ((a)->connect(a, f))
+void afinet_src_set_localport(struct log_source_driver *c, UINT32 port);
+void afinet_src_set_localip(struct log_source_driver *c, const char *ip);
+void afinet_src_set_auth(struct log_source_driver *c, UINT32 v);
+void afinet_src_set_mac(struct log_source_driver *c, UINT32 v);
+void afinet_src_set_encrypt(struct log_source_driver *c, UINT32 v);
 
-struct socket_addr *make_unix_addr(const char *name);
-struct socket_addr *make_inet_addr(struct in_addr host, unsigned short port);
+void afinet_dest_set_localip(struct log_dest_driver *c, const char *ip);
+void afinet_dest_set_localport(struct log_dest_driver *c, UINT32 port);
+void afinet_dest_set_destport(struct log_dest_driver *c, UINT32 port);
+void afinet_dest_set_auth(struct log_dest_driver *c, UINT32 value);
+void afinet_dest_set_mac(struct log_dest_driver *c, UINT32 value);
+void afinet_dest_set_encrypt(struct log_dest_driver *c, UINT32 value);
 
-struct log_source_driver *make_afsocket_source(struct socket_addr *sa, UINT32 flags);
-struct log_dest_driver *make_afsocket_dest(struct socket_addr *sa, UINT32 flags);
+struct log_source_driver *make_afsocket_source(struct address_info *a, UINT32 flags);
+struct log_dest_driver *make_afsocket_dest(struct address_info *a, UINT32 flags);
 
 
 #endif
