@@ -18,7 +18,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: cfgfile.c,v 1.17 1999/07/10 15:58:33 bazsi Exp $
+ * $Id: cfgfile.c,v 1.18 1999/07/18 12:56:11 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -62,7 +62,8 @@ void add_log_connection(struct log_connection *conn)
 
 #define RESOLVE_VAR(s, first, next, i) \
         for (s = first; s; s = s->next) { \
-	         if (strncmp(i->name->data, s->name->data, i->name->length) == 0) { \
+	         if (i->name->length == s->name->length && \
+		     strncmp(i->name->data, s->name->data, i->name->length) == 0) { \
 			 i->ref = (struct ol_object *) s; \
 			 break; \
 		 } \
@@ -154,7 +155,7 @@ struct syslog_conf *make_syslog_conf(const char *name, struct io_backend *backen
 	self->init = do_init_config;
 	self->destroy = do_destroy_config;
 	self->backend = backend;
-	self->sync_freq = 1;
+	self->sync_freq = 0;
 	self->mark_freq = 1200; /* 20 minutes */
 	self->long_hostnames = 1;
 	self->time_reopen = 60;
